%%%-------------------------------------------------------------------
%%% File    : iwd_supervisor.erl
%%% Author  : Igor Wojnicki <wojnicki@rabbit>
%%% Description : iwd Supervisor
%%%
%%% Created : 26 Jan 2011 by Igor Wojnicki <wojnicki@rabbit>
%%%-------------------------------------------------------------------
-module(iwd_supervisor).

-behaviour(supervisor).

%% API
-export([start_link/1,start_in_shell_for_testing/0]).

%% Supervisor callbacks
-export([init/1]).

-define(SERVER, ?MODULE).

%%====================================================================
%% API functions
%%====================================================================
%%--------------------------------------------------------------------
%% Function: start_link() -> {ok,Pid} | ignore | {error,Error}
%% Description: Starts the supervisor
%%--------------------------------------------------------------------
start_link(Args) ->
    supervisor:start_link({local, ?MODULE}, ?MODULE, Args).

start_in_shell_for_testing() ->
    {ok, Pid} = supervisor:start_link({local,?MODULE}, ?MODULE, []),
    unlink(Pid).

%%====================================================================
%% Supervisor callbacks
%%====================================================================
%%--------------------------------------------------------------------
%% Func: init(Args) -> {ok,  {SupFlags,  [ChildSpec]}} |
%%                     ignore                          |
%%                     {error, Reason}
%% Description: Whenever a supervisor is started using 
%% supervisor:start_link/[2,3], this function is called by the new process 
%% to find out about restart strategy, maximum restart frequency and child 
%% specifications.
%%--------------------------------------------------------------------
init([]) ->
    {ok, {{one_for_one, 3, 10},
	  [{tag1, 
	    {iwd, start_link, []},
	    permanent, 
	    10000, 
	    worker, 
	    [iwd]}
	  ]}}.

%%====================================================================
%% Internal functions
%%====================================================================
